# epigenetics analysis kit

A toolkit for analysis and processing of epigenetics datasets.

```
    pip install epikit
```

## epicheck

This tool checks the integrity of a 4D epigenetics dataset

```
    epicheck --ensemble path/to/ensemble
```

## epigen

This tool processes the result files in a 4D genetics dataset and generates
missing metadata as required in the final data specification.

```
    epigen --ensemble path/to/ensemble
```

